import Taro, { Component } from '@tarojs/taro'
import { View, Button, Image } from '@tarojs/components'
import { createAction } from '@utils/redux'
import './index.scss'


export default class ImagePicker extends Component {
  static defaultProps = {
    time: Date.parse(new Date()),
  }

  getStorage(key) {
    return Taro.getStorage({ key }).then(res => res.data).catch(() => '')
  }

  async handleUpload() {
    const { num = 1, id } = this.props
    const token = await this.getStorage('token')
    Taro.chooseImage({
      count: num, // 最多选择多少张图片
      sizeType: ['compressed'], // 压缩图像文件
      sourceType: ['album', 'camera'], // 从相册和相机选择图片
      success: (res) => {
        const files = res.tempFilePaths;

        // 上传每张图片到服务器
        files.forEach((file) => {
          Taro.uploadFile({
            url: 'http://140.210.193.73/gw/user/logo', // 上传接口地址
            filePath: file,
            header: {
              'Authorization': token,
            },
            formData: {
              reportId: !!id && id,
            },
            name: 'file', // 服务端接收的文件字段名
            success: (result) => {
              if (result.statusCode === 200) {
                const responseData = JSON.parse(result.data); // 服务器返回的数据
                // 可以根据服务器返回的数据做一些逻辑处理
                const { imageUrls } = this.state;
                this.setState({ token, imageUrls: [responseData.data] })
                // this.setState({ imageUrls: [...imageUrls, ...[responseData.data]] });
              } else {
                // 处理上传失败的情况
                Taro.showToast({
                  title: '上传失败',
                  icon: 'none',
                  mask: true
                })
              }
            },
            fail: (error) => {
              // 处理上传失败的情况
              Taro.showToast({
                title: '上传失败',
                icon: 'none',
                mask: true
              })
            },
          });
        });
      },
    });
  }

  deleteImg = createAction({
    url: "http://140.210.193.73/gw/user/logo" + `/${this.props.id}`,
    method: 'DELETE',
    type: 'TEMPLATE_DELETE',
    payload: {},
  })

  handleDelete(index) {
    const { imageUrls } = this.state;
    const updatedUrls = [...imageUrls];
    this.deleteImg()
    updatedUrls.splice(index, 1);
    this.setState({ imageUrls: updatedUrls });

  }

  handlePreview(index) {
    const { id, time } = this.props
    const { imageUrls, token } = this.state;
    const urls = imageUrls.map((url) => `http://140.210.193.73/gw/user/logo/${id}?token=${token}&t=${time}`);
    Taro.previewImage({
      urls,
      current: urls[index],
      fail: (error) => {
        // 处理预览失败的情况
      },
    });
  }

  render() {
    const { imageUrls = [], token } = this.state
    const { time, id, num = 1 } = this.props
    return (
      <View className='upload'>
        {imageUrls && imageUrls.map((url, index) => (
          <View className='upload-item' key={index}>
            <Image
              className='upload-item-img'
              src={`http://140.210.193.73/gw/user/logo/${id}?token=${token}&t=${time}`}
              mode='aspectFit'
              onClick={() => this.handlePreview(index)}
            />
            <View className='upload-item-delete'
              onClick={this.handleDelete.bind(this, index)}
            >
              删除
            </View>
          </View>
        ))}
        {imageUrls.length < num && <View className='upload-add' onClick={this.handleUpload.bind(this)}>+</View>}
      </View>
    )
  }
}

